<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage GARDIS
 * @since GARDIS 1.0
 */

$gardis_blog_style = explode('_', gardis_get_theme_option('blog_style'));
$gardis_columns = empty($gardis_blog_style[1]) ? 1 : max(1, $gardis_blog_style[1]);
$gardis_expanded = !gardis_sidebar_present() && gardis_is_on(gardis_get_theme_option('expand_content'));
$gardis_post_format = get_post_format();
$gardis_post_format = empty($gardis_post_format) ? 'standard' : str_replace('post-format-', '', $gardis_post_format);
$gardis_animation = gardis_get_theme_option('blog_animation');

?><article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_chess post_layout_chess_'.esc_attr($gardis_columns).' post_format_'.esc_attr($gardis_post_format) ); ?>
	<?php echo (!gardis_is_off($gardis_animation) ? ' data-animation="'.esc_attr(gardis_get_animation_classes($gardis_animation)).'"' : ''); ?>>

	<?php
	// Add anchor
	if ($gardis_columns == 1 && shortcode_exists('trx_sc_anchor')) {
		echo do_shortcode('[trx_sc_anchor id="post_'.esc_attr(get_the_ID()).'" title="'.the_title_attribute( array( 'echo' => false ) ).'"]');
	}

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	gardis_show_post_featured( array(
											'class' => $gardis_columns == 1 ? 'gardis-full-height' : '',
											'show_no_image' => true,
											'thumb_bg' => true,
											'thumb_size' => gardis_get_thumb_size(
																	strpos(gardis_get_theme_option('body_style'), 'full')!==false
																		? ( $gardis_columns > 1 ? 'huge' : 'original' )
																		: (	$gardis_columns > 2 ? 'big' : 'huge')
																	)
											) 
										);

	?><div class="post_inner"><div class="post_inner_content"><?php 

		?><div class="post_header entry-header"><?php 
			do_action('gardis_action_before_post_title'); 

			// Post title
			the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
			
			do_action('gardis_action_before_post_meta'); 

			// Post meta
			$gardis_components = gardis_is_inherit(gardis_get_theme_option_from_meta('meta_parts')) 
										? 'author'.($gardis_columns < 3 ? ',date' : '').($gardis_columns < 2 ? ',counters' : '')
										: gardis_array_get_keys_by_value(gardis_get_theme_option('meta_parts'));
			$gardis_counters = gardis_is_inherit(gardis_get_theme_option_from_meta('counters')) 
										? 'comments'
										: gardis_array_get_keys_by_value(gardis_get_theme_option('counters'));
			$gardis_post_meta = empty($gardis_components) 
										? '' 
										: gardis_show_post_meta(apply_filters('gardis_filter_post_meta_args', array(
												'components' => $gardis_components,
												'counters' => $gardis_counters,
												'seo' => false,
												'echo' => false
												), $gardis_blog_style[0], $gardis_columns)
											);
			gardis_show_layout($gardis_post_meta);
		?></div><!-- .entry-header -->
	
		<div class="post_content entry-content">
			<div class="post_content_inner">
				<?php
				$gardis_show_learn_more = !in_array($gardis_post_format, array('link', 'aside', 'status', 'quote'));
				if (has_excerpt()) {
					the_excerpt();
				} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
					the_content( '' );
				} else if (in_array($gardis_post_format, array('link', 'aside', 'status'))) {
					the_content();
				} else if ($gardis_post_format == 'quote') {
					if (($quote = gardis_get_tag(get_the_content(), '<blockquote>', '</blockquote>'))!='')
						gardis_show_layout(wpautop($quote));
					else
						the_excerpt();
				} else if (substr(get_the_content(), 0, 1)!='[') {
					the_excerpt();
				}
				?>
			</div>
			<?php
			// Post meta
			if (in_array($gardis_post_format, array('link', 'aside', 'status', 'quote'))) {
				gardis_show_layout($gardis_post_meta);
			}
			// More button
			if ( $gardis_show_learn_more ) {
				?><p><a class="more-link" href="<?php the_permalink(); ?>"><?php esc_html_e('Read more', 'gardis'); ?></a></p><?php
			}
			?>
		</div><!-- .entry-content -->

	</div></div><!-- .post_inner -->

</article>