<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage GARDIS
 * @since GARDIS 1.0
 */

$gardis_blog_style = explode('_', gardis_get_theme_option('blog_style'));
$gardis_columns = empty($gardis_blog_style[1]) ? 2 : max(2, $gardis_blog_style[1]);
$gardis_expanded = !gardis_sidebar_present() && gardis_is_on(gardis_get_theme_option('expand_content'));
$gardis_post_format = get_post_format();
$gardis_post_format = empty($gardis_post_format) ? 'standard' : str_replace('post-format-', '', $gardis_post_format);
$gardis_animation = gardis_get_theme_option('blog_animation');
$gardis_components = gardis_is_inherit(gardis_get_theme_option_from_meta('meta_parts')) 
							? 'date,counters'
							: gardis_array_get_keys_by_value(gardis_get_theme_option('meta_parts'));
$gardis_counters = gardis_is_inherit(gardis_get_theme_option_from_meta('counters')) 
							? 'comments'
							: gardis_array_get_keys_by_value(gardis_get_theme_option('counters'));

?><div class="<?php echo esc_html($gardis_blog_style[0] == 'classic' ? 'column' : 'masonry_item masonry_item'); ?>-1_<?php echo esc_attr($gardis_columns); ?>"><article id="post-<?php the_ID(); ?>"
	<?php post_class( 'post_item post_format_'.esc_attr($gardis_post_format)
					. ' post_layout_classic post_layout_classic_'.esc_attr($gardis_columns)
					. ' post_layout_'.esc_attr($gardis_blog_style[0]) 
					. ' post_layout_'.esc_attr($gardis_blog_style[0]).'_'.esc_attr($gardis_columns)
					); ?>
	<?php echo (!gardis_is_off($gardis_animation) ? ' data-animation="'.esc_attr(gardis_get_animation_classes($gardis_animation)).'"' : ''); ?>>
	<?php

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	gardis_show_post_featured( array( 'thumb_size' => gardis_get_thumb_size($gardis_blog_style[0] == 'classic'
													? (strpos(gardis_get_theme_option('body_style'), 'full')!==false 
															? ( $gardis_columns > 2 ? 'big' : 'huge' )
															: (	$gardis_columns > 2
																? ($gardis_expanded ? 'med' : 'small')
																: ($gardis_expanded ? 'big' : 'med')
																)
														)
													: (strpos(gardis_get_theme_option('body_style'), 'full')!==false 
															? ( $gardis_columns > 2 ? 'masonry-big' : 'full' )
															: (	$gardis_columns <= 2 && $gardis_expanded ? 'masonry-big' : 'masonry')
														)
								) ) );

	if ( !in_array($gardis_post_format, array('link', 'aside', 'status', 'quote')) ) {
		?>
		<div class="post_header entry-header">
			<?php 
			do_action('gardis_action_before_post_title'); 

			// Post title
			the_title( sprintf( '<h5 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h5>' );

			do_action('gardis_action_before_post_meta'); 

			// Post meta
			if (!empty($gardis_components))
				gardis_show_post_meta(apply_filters('gardis_filter_post_meta_args', array(
					'components' => $gardis_components,
					'counters' => $gardis_counters,
					'seo' => false
					), $gardis_blog_style[0], $gardis_columns)
				);

			do_action('gardis_action_after_post_meta'); 
			?>
		</div><!-- .entry-header -->
		<?php
	}		
	?>

	<div class="post_content entry-content">
		<div class="post_content_inner">
			<?php
			$gardis_show_learn_more = false;
			if (has_excerpt()) {
				the_excerpt();
			} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
				the_content( '' );
			} else if (in_array($gardis_post_format, array('link', 'aside', 'status'))) {
				the_content();
			} else if ($gardis_post_format == 'quote') {
				if (($quote = gardis_get_tag(get_the_content(), '<blockquote>', '</blockquote>'))!='')
					gardis_show_layout(wpautop($quote));
				else
					the_excerpt();
			} else if (substr(get_the_content(), 0, 1)!='[') {
				the_excerpt();
			}
			?>
		</div>
		<?php
		// Post meta
		if (in_array($gardis_post_format, array('link', 'aside', 'status', 'quote'))) {
			if (!empty($gardis_components))
				gardis_show_post_meta(apply_filters('gardis_filter_post_meta_args', array(
					'components' => $gardis_components,
					'counters' => $gardis_counters
					), $gardis_blog_style[0], $gardis_columns)
				);
		}
		// More button
		if ( $gardis_show_learn_more ) {
			?><p><a class="more-link" href="<?php the_permalink(); ?>"><?php esc_html_e('Read more', 'gardis'); ?></a></p><?php
		}
		?>
	</div><!-- .entry-content -->

</article></div>