<?php
/**
 * The default template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage GARDIS
 * @since GARDIS 1.0
 */

$gardis_post_format = get_post_format();
$gardis_post_format = empty($gardis_post_format) ? 'standard' : str_replace('post-format-', '', $gardis_post_format);
$gardis_animation = gardis_get_theme_option('blog_animation');

?><article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_excerpt post_format_'.esc_attr($gardis_post_format) ); ?>
	<?php echo (!gardis_is_off($gardis_animation) ? ' data-animation="'.esc_attr(gardis_get_animation_classes($gardis_animation)).'"' : ''); ?>
	><?php

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

    // Title and post meta
    if (get_the_title() != '') {
        ?>
        <div class="post_header entry-header">
            <?php
            do_action('gardis_action_before_post_title');

            // Post title
            the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );

            do_action('gardis_action_before_post_meta');

            // Post meta
            $gardis_components = gardis_is_inherit(gardis_get_theme_option_from_meta('meta_parts'))
                ? 'author,date,categories,counters'
                : gardis_array_get_keys_by_value(gardis_get_theme_option('meta_parts'));
            $gardis_counters = gardis_is_inherit(gardis_get_theme_option_from_meta('counters'))
                ? 'comments'
                : gardis_array_get_keys_by_value(gardis_get_theme_option('counters'));

            if (!empty($gardis_components))
                gardis_show_post_meta(apply_filters('gardis_filter_post_meta_args', array(
                        'components' => $gardis_components,
                        'counters' => $gardis_counters,
                        'seo' => false
                    ), 'excerpt', 1)
                );
            ?>
        </div><!-- .post_header --><?php
    }

	// Featured image
	gardis_show_post_featured(array( 'thumb_size' => gardis_get_thumb_size( strpos(gardis_get_theme_option('body_style'), 'full')!==false ? 'full' : 'big' ) ));


	
	// Post content
	?><div class="post_content entry-content"><?php
		if (gardis_get_theme_option('blog_content') == 'fullpost') {
			// Post content area
			?><div class="post_content_inner"><?php
				the_content( '' );
			?></div><?php
			// Inner pages
			wp_link_pages( array(
				'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'gardis' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'gardis' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text">, </span>',
			) );

		} else {

			$gardis_show_learn_more = !in_array($gardis_post_format, array('link', 'aside', 'status', 'quote'));

			// Post content area
			?><div class="post_content_inner"><?php
				if (has_excerpt()) {
					the_excerpt();
				} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
					the_content( '' );
				} else if (in_array($gardis_post_format, array('link', 'aside', 'status'))) {
					the_content();
				} else if ($gardis_post_format == 'quote') {
					if (($quote = gardis_get_tag(get_the_content(), '<blockquote>', '</blockquote>'))!='')
						gardis_show_layout(wpautop($quote));
					else
						the_excerpt();
				} else if (substr(get_the_content(), 0, 1)!='[') {
					the_excerpt();
				}
			?></div><?php
			// More button
			if ( $gardis_show_learn_more ) {
				?><p><a class="more-link" href="<?php the_permalink(); ?>"><?php esc_html_e('Read more', 'gardis'); ?></a></p><?php
			}

		}
	?></div><!-- .entry-content -->
</article>