<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage GARDIS
 * @since GARDIS 1.0
 */

gardis_storage_set('blog_archive', true);

get_header(); 

if (have_posts()) {

	gardis_show_layout(get_query_var('blog_archive_start'));

	$gardis_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$gardis_sticky_out = gardis_get_theme_option('sticky_style')=='columns' 
							&& is_array($gardis_stickies) && count($gardis_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$gardis_cat = gardis_get_theme_option('parent_cat');
	$gardis_post_type = gardis_get_theme_option('post_type');
	$gardis_taxonomy = gardis_get_post_type_taxonomy($gardis_post_type);
	$gardis_show_filters = gardis_get_theme_option('show_filters');
	$gardis_tabs = array();
	if (!gardis_is_off($gardis_show_filters)) {
		$gardis_args = array(
			'type'			=> $gardis_post_type,
			'child_of'		=> $gardis_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $gardis_taxonomy,
			'pad_counts'	=> false
		);
		$gardis_portfolio_list = get_terms($gardis_args);
		if (is_array($gardis_portfolio_list) && count($gardis_portfolio_list) > 0) {
			$gardis_tabs[$gardis_cat] = esc_html__('All', 'gardis');
			foreach ($gardis_portfolio_list as $gardis_term) {
				if (isset($gardis_term->term_id)) $gardis_tabs[$gardis_term->term_id] = $gardis_term->name;
			}
		}
	}
	if (count($gardis_tabs) > 0) {
		$gardis_portfolio_filters_ajax = true;
		$gardis_portfolio_filters_active = $gardis_cat;
		$gardis_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters gardis_tabs gardis_tabs_ajax">
			<ul class="portfolio_titles gardis_tabs_titles">
				<?php
				foreach ($gardis_tabs as $gardis_id=>$gardis_title) {
					?><li><a href="<?php echo esc_url(gardis_get_hash_link(sprintf('#%s_%s_content', $gardis_portfolio_filters_id, $gardis_id))); ?>" data-tab="<?php echo esc_attr($gardis_id); ?>"><?php echo esc_html($gardis_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$gardis_ppp = gardis_get_theme_option('posts_per_page');
			if (gardis_is_inherit($gardis_ppp)) $gardis_ppp = '';
			foreach ($gardis_tabs as $gardis_id=>$gardis_title) {
				$gardis_portfolio_need_content = $gardis_id==$gardis_portfolio_filters_active || !$gardis_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $gardis_portfolio_filters_id, $gardis_id)); ?>"
					class="portfolio_content gardis_tabs_content"
					data-blog-template="<?php echo esc_attr(gardis_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(gardis_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($gardis_ppp); ?>"
					data-post-type="<?php echo esc_attr($gardis_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($gardis_taxonomy); ?>"
					data-cat="<?php echo esc_attr($gardis_id); ?>"
					data-parent-cat="<?php echo esc_attr($gardis_cat); ?>"
					data-need-content="<?php echo (false===$gardis_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($gardis_portfolio_need_content) 
						gardis_show_portfolio_posts(array(
							'cat' => $gardis_id,
							'parent_cat' => $gardis_cat,
							'taxonomy' => $gardis_taxonomy,
							'post_type' => $gardis_post_type,
							'page' => 1,
							'sticky' => $gardis_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		gardis_show_portfolio_posts(array(
			'cat' => $gardis_cat,
			'parent_cat' => $gardis_cat,
			'taxonomy' => $gardis_taxonomy,
			'post_type' => $gardis_post_type,
			'page' => 1,
			'sticky' => $gardis_sticky_out
			)
		);
	}

	gardis_show_layout(get_query_var('blog_archive_end'));

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>