<?php
/**
 * Setup theme-specific fonts and colors
 *
 * @package WordPress
 * @subpackage GARDIS
 * @since GARDIS 1.0.22
 */

if (!defined("GARDIS_THEME_FREE")) define("GARDIS_THEME_FREE", false);
if (!defined("GARDIS_THEME_FREE_WP")) define("GARDIS_THEME_FREE_WP", false);

// Theme storage
$GARDIS_STORAGE = array(
	// Theme required plugin's slugs
	'required_plugins' => array_merge(

		// List of plugins for both - FREE and PREMIUM versions
		//-----------------------------------------------------
		array(
			// Required plugins
			// DON'T COMMENT OR REMOVE NEXT LINES!
			'trx_addons'					=> esc_html__('ThemeREX Addons', 'gardis'),

			// Recommended (supported) plugins fot both (lite and full) versions
			// If plugin not need - comment (or remove) it
			'contact-form-7'				=> esc_html__('Contact Form 7', 'gardis'),
			'mailchimp-for-wp'				=> esc_html__('MailChimp for WP', 'gardis'),
			'wp-gdpr-compliance'			=> esc_html__('WP GDPR Compliance', 'gardis'),
			'woocommerce'					=> esc_html__('WooCommerce', 'gardis'),
            'trx_updater'					=> esc_html__('ThemeREX Updater', 'gardis'),
            'elegro-payment'				=> esc_html__('elegro Crypto Payment', 'gardis'),



		),

		// List of plugins for PREMIUM version only
		//-----------------------------------------------------
		GARDIS_THEME_FREE 
			? array(
					// Recommended (supported) plugins for the FREE (lite) version
					)
			: array(
					// Recommended (supported) plugins for the PRO (full) version
					// If plugin not need - comment (or remove) it
					'js_composer'				=> esc_html__('WPBakery Page Builder', 'gardis'),
					'essential-grid'			=> esc_html__('Essential Grid', 'gardis'),
					'revslider'					=> esc_html__('Revolution Slider', 'gardis')
				)
	),
	
	// Theme-specific URLs (will be escaped in place of the output)
	'theme_demo_url' => 'http://gardis.ancorathemes.com',
	'theme_doc_url'  => 'http://gardis.ancorathemes.com/doc',

	'theme_video_url'    => 'https://www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',  // Ancora

	'theme_support_url'  => 'http://ancorathemes.com/theme-support/',                    // Ancora

	'theme_privacy_url'  => 'http://ancorathemes.com/privacy-policy/',                   // Ancora

	'theme_download_url'=> 'https://1.envato.market/c/1262870/275988/4415?subId1=ancora&u=themeforest.net/item/gardis-blinds-and-curtains-studio-shop/20918466',
);

// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)

if ( !function_exists('gardis_customizer_theme_setup1') ) {
	add_action( 'after_setup_theme', 'gardis_customizer_theme_setup1', 1 );
	function gardis_customizer_theme_setup1() {

		// -----------------------------------------------------------------
		// -- ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
		// -- Internal theme settings
		// -----------------------------------------------------------------
		gardis_storage_set('settings', array(
			
			'duplicate_options'		=> 'both',		// none  - use separate options for template and child-theme
													// child - duplicate theme options from the main theme to the child-theme only
													// both  - sinchronize changes in the theme options between main and child themes
			
			'custmize_refresh'		=> 'auto',		// Refresh method for preview area in the Appearance - Customize:
													// auto - refresh preview area on change each field with Theme Options
													// manual - refresh only obn press button 'Refresh' at the top of Customize frame
		
			'max_load_fonts'		=> 5,			// Max fonts number to load from Google fonts or from uploaded fonts
		
			'comment_maxlength'		=> 1000,		// Max length of the message from contact form

			'comment_after_name'	=> true,		// Place 'comment' field before the 'name' and 'email'
			
			'socials_type'			=> 'icons',		// Type of socials:
													// icons - use font icons to present social networks
													// images - use images from theme's folder trx_addons/css/icons.png
			
			'icons_type'			=> 'icons',		// Type of other icons:
													// icons - use font icons to present icons
													// images - use images from theme's folder trx_addons/css/icons.png
			
			'icons_selector'		=> 'internal',	// Icons selector in the shortcodes:
													//standard VC icons selector (very slow and don't support images)
													// internal - internal popup with plugin's or theme's icons list (fast)
			'check_min_version'		=> true,		// Check if exists a .min version of .css and .js and return path to it
													// instead the path to the original file
													// (if debug_mode is off and modification time of the original file < time of the .min file)
			'autoselect_menu'		=> true,		// Show any menu if no menu selected in the location 'main_menu'
													// (for example, the theme is just activated)
			'disable_jquery_ui'		=> false,		// Prevent loading custom jQuery UI libraries in the third-party plugins
		
			'use_mediaelements'		=> true,		// Load script "Media Elements" to play video and audio
			
			'tgmpa_upload'			=> false		// Allow upload not pre-packaged plugins via TGMPA
		));


		// -----------------------------------------------------------------
		// -- Theme fonts (Google and/or custom fonts)
		// -----------------------------------------------------------------
		
		// Fonts to load when theme start
		// It can be Google fonts or uploaded fonts, placed in the folder /css/font-face/font-name inside the theme folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		
		gardis_storage_set('load_fonts', array(
			// Google font
			array(
				'name'	 => 'Lora',
				'family' => 'serif',
				'styles' => '400,400i'		// Parameter 'style' used only for the Google fonts
				),
            array(
                'name'	 => 'Cinzel',
                'family' => 'serif',
                'styles' => '700'		// Parameter 'style' used only for the Google fonts
            ),

            // Font-face packed with theme
            array(
                'name'	 => 'Questrial',
                'family' => 'sans-serif'
            ),
		));
		
		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		gardis_storage_set('load_fonts_subset', 'latin,latin-ext');
		
		// Settings of the main tags
		gardis_storage_set('theme_fonts', array(
			'p' => array(
				'title'				=> esc_html__('Main text', 'gardis'),
				'description'		=> esc_html__('Font settings of the main text of the site', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '16px',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '24px',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-0.03px',
				'margin-top'		=> '0em',
				'margin-bottom'		=> '1.5em'
				),
			'h1' => array(
				'title'				=> esc_html__('Heading 1', 'gardis'),
				'font-family'		=> '"Lora",serif',
				'font-size' 		=> '3.75em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.23em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '9.45rem',
				'margin-bottom'		=> '3.6rem'
				),
			'h2' => array(
				'title'				=> esc_html__('Heading 2', 'gardis'),
				'font-family'		=> '"Lora",serif',
				'font-size' 		=> '3em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.23em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '9.7rem',
				'margin-bottom'		=> '2.4rem'
				),
			'h3' => array(
				'title'				=> esc_html__('Heading 3', 'gardis'),
				'font-family'		=> '"Lora",serif',
				'font-size' 		=> '2.25em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.21em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '10rem',
				'margin-bottom'		=> '2.2rem'
				),
			'h4' => array(
				'title'				=> esc_html__('Heading 4', 'gardis'),
				'font-family'		=> '"Lora",serif',
				'font-size' 		=> '1.875em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.29em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '10rem',
				'margin-bottom'		=> '2rem'
				),
			'h5' => array(
				'title'				=> esc_html__('Heading 5', 'gardis'),
				'font-family'		=> '"Lora",serif',
				'font-size' 		=> '1.5em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.4em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '10rem',
				'margin-bottom'		=> '1.95rem'
				),
			'h6' => array(
				'title'				=> esc_html__('Heading 6', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '1.125em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.37em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '10.15rem',
				'margin-bottom'		=> '1.6rem'
				),
			'logo' => array(
				'title'				=> esc_html__('Logo text', 'gardis'),
				'description'		=> esc_html__('Font settings of the text case of the logo', 'gardis'),
				'font-family'		=> '"Cinzel",serif',
				'font-size' 		=> '2.063em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.25em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '0px'
				),
			'button' => array(
				'title'				=> esc_html__('Buttons', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '1em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0.92px'
				),
			'input' => array(
				'title'				=> esc_html__('Input fields', 'gardis'),
				'description'		=> esc_html__('Font settings of the input fields, dropdowns and textareas', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '1em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.2em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px'
				),
			'info' => array(
				'title'				=> esc_html__('Post meta', 'gardis'),
				'description'		=> esc_html__('Font settings of the post meta: date, counters, share, etc.', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '1em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '0.4em',
				'margin-bottom'		=> ''
				),
			'menu' => array(
				'title'				=> esc_html__('Main menu', 'gardis'),
				'description'		=> esc_html__('Font settings of the main menu items', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '1em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '1.1px'
				),
			'submenu' => array(
				'title'				=> esc_html__('Dropdown menu', 'gardis'),
				'description'		=> esc_html__('Font settings of the dropdown menu items', 'gardis'),
				'font-family'		=> '"Questrial",sans-serif',
				'font-size' 		=> '1em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0.9px'
				)
		));
		
		
		// -----------------------------------------------------------------
		// -- Theme colors for customizer
		// -- Attention! Inner scheme must be last in the array below
		// -----------------------------------------------------------------
		gardis_storage_set('scheme_color_groups', array(
			'main'	=> array(
							'title'			=> esc_html__('Main', 'gardis'),
							'description'	=> esc_html__('Colors of the main content area', 'gardis')
							),
			'alter'	=> array(
							'title'			=> esc_html__('Alter', 'gardis'),
							'description'	=> esc_html__('Colors of the alternative blocks (sidebars, etc.)', 'gardis')
							),
			'extra'	=> array(
							'title'			=> esc_html__('Extra', 'gardis'),
							'description'	=> esc_html__('Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'gardis')
							),
			'inverse' => array(
							'title'			=> esc_html__('Inverse', 'gardis'),
							'description'	=> esc_html__('Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'gardis')
							),
			'input'	=> array(
							'title'			=> esc_html__('Input', 'gardis'),
							'description'	=> esc_html__('Colors of the form fields (text field, textarea, select, etc.)', 'gardis')
							),
			)
		);
		gardis_storage_set('scheme_color_names', array(
			'bg_color'	=> array(
							'title'			=> esc_html__('Background color', 'gardis'),
							'description'	=> esc_html__('Background color of this block in the normal state', 'gardis')
							),
			'bg_hover'	=> array(
							'title'			=> esc_html__('Background hover', 'gardis'),
							'description'	=> esc_html__('Background color of this block in the hovered state', 'gardis')
							),
			'bd_color'	=> array(
							'title'			=> esc_html__('Border color', 'gardis'),
							'description'	=> esc_html__('Border color of this block in the normal state', 'gardis')
							),
			'bd_hover'	=>  array(
							'title'			=> esc_html__('Border hover', 'gardis'),
							'description'	=> esc_html__('Border color of this block in the hovered state', 'gardis')
							),
			'text'		=> array(
							'title'			=> esc_html__('Text', 'gardis'),
							'description'	=> esc_html__('Color of the plain text inside this block', 'gardis')
							),
			'text_dark'	=> array(
							'title'			=> esc_html__('Text dark', 'gardis'),
							'description'	=> esc_html__('Color of the dark text (bold, header, etc.) inside this block', 'gardis')
							),
			'text_light'=> array(
							'title'			=> esc_html__('Text light', 'gardis'),
							'description'	=> esc_html__('Color of the light text (post meta, etc.) inside this block', 'gardis')
							),
			'text_link'	=> array(
							'title'			=> esc_html__('Link', 'gardis'),
							'description'	=> esc_html__('Color of the links inside this block', 'gardis')
							),
			'text_hover'=> array(
							'title'			=> esc_html__('Link hover', 'gardis'),
							'description'	=> esc_html__('Color of the hovered state of links inside this block', 'gardis')
							),
			'text_link2'=> array(
							'title'			=> esc_html__('Link 2', 'gardis'),
							'description'	=> esc_html__('Color of the accented texts (areas) inside this block', 'gardis')
							),
			'text_hover2'=> array(
							'title'			=> esc_html__('Link 2 hover', 'gardis'),
							'description'	=> esc_html__('Color of the hovered state of accented texts (areas) inside this block', 'gardis')
							),
			'text_link3'=> array(
							'title'			=> esc_html__('Link 3', 'gardis'),
							'description'	=> esc_html__('Color of the other accented texts (buttons) inside this block', 'gardis')
							),
			'text_hover3'=> array(
							'title'			=> esc_html__('Link 3 hover', 'gardis'),
							'description'	=> esc_html__('Color of the hovered state of other accented texts (buttons) inside this block', 'gardis')
							)
			)
		);
		gardis_storage_set('schemes', array(
		
			// Color scheme: 'default'
			'default' => array(
				'title'	 => esc_html__('Default', 'gardis'),
				'colors' => array(
					
					// Whole block border and background
					'bg_color'			=> '#ffffff',   //
					'bd_color'			=> '#cfd6db',   //
		
					// Text and links colors
					'text'				=> '#909aa1',   //
					'text_light'		=> '#909aa1',   //
					'text_dark'			=> '#103449',   //
					'text_link'			=> '#1c97cb',   //
					'text_hover'		=> '#103449',   //
					'text_link2'		=> '#fdce4b',   //
					'text_hover2'		=> '#60707d',   //
					'text_link3'		=> '#ddb837',
					'text_hover3'		=> '#eec432',
		
					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'	=> '#f1f8fe',   //
					'alter_bg_hover'	=> '#e2ecf4',   //
					'alter_bd_color'	=> '#dae7f1',   //
					'alter_bd_hover'	=> '#dadada',
					'alter_text'		=> '#333333',
					'alter_light'		=> '#8497a6',   //
					'alter_dark'		=> '#103449',   //
					'alter_link'		=> '#1c97cb',   //
					'alter_hover'		=> '#72cfd5',
					'alter_link2'		=> '#8be77c',
					'alter_hover2'		=> '#80d572',
					'alter_link3'		=> '#eec432',
					'alter_hover3'		=> '#ddb837',
		
					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'	=> '#2399ca',   //
					'extra_bg_hover'	=> '#28272e',
					'extra_bd_color'	=> '#313131',
					'extra_bd_hover'	=> '#3d3d3d',
					'extra_text'		=> '#bfbfbf',
					'extra_light'		=> '#afafaf',
					'extra_dark'		=> '#ffffff',   //
					'extra_link'		=> '#ffffff',   //
					'extra_hover'		=> '#fe7259',
					'extra_link2'		=> '#80d572',
					'extra_hover2'		=> '#8be77c',
					'extra_link3'		=> '#ddb837',
					'extra_hover3'		=> '#eec432',
		
					// Input fields (form's fields and textarea)
					'input_bg_color'	=> '#e8f1f9',   //
					'input_bg_hover'	=> '#e8f1f9',   //
					'input_bd_color'	=> '#e8f1f9',   //
					'input_bd_hover'	=> '#2399ca',   //
					'input_text'		=> '#909aa1',   //
					'input_light'		=> '#909aa1',   //
					'input_dark'		=> '#103449',   //
					
					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color'	=> '#67bcc1',
					'inverse_bd_hover'	=> '#5aa4a9',
					'inverse_text'		=> '#1d1d1d',
					'inverse_light'		=> '#333333',
					'inverse_dark'		=> '#0c2636',   //
					'inverse_link'		=> '#ffffff',
					'inverse_hover'		=> '#1d1d1d'
				)
			),
		
			// Color scheme: 'dark'
			'dark' => array(
				'title'  => esc_html__('Dark', 'gardis'),
				'colors' => array(
					
					// Whole block border and background
					'bg_color'			=> '#0c2636',   //
					'bd_color'			=> '#2e2c33',
		
					// Text and links colors
					'text'				=> '#b7b7b7',
					'text_light'		=> '#5f5f5f',
					'text_dark'			=> '#ffffff',
                    'text_link'			=> '#1c97cb',   //
                    'text_hover'		=> '#103449',   //
                    'text_link2'		=> '#fdce4b',   //
                    'text_hover2'		=> '#60707d',   //
					'text_link3'		=> '#ddb837',
					'text_hover3'		=> '#eec432',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'	=> '#0c2636',   //
					'alter_bg_hover'	=> '#333333',
					'alter_bd_color'	=> '#464646',
					'alter_bd_hover'	=> '#4a4a4a',
					'alter_text'		=> '#88929a',   //
					'alter_light'		=> '#5f5f5f',
					'alter_dark'		=> '#ffffff',
					'alter_link'		=> '#1c97cb',
					'alter_hover'		=> '#fe7259',
					'alter_link2'		=> '#8be77c',
					'alter_hover2'		=> '#80d572',
					'alter_link3'		=> '#eec432',
					'alter_hover3'		=> '#ddb837',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'	=> '#1e1d22',
					'extra_bg_hover'	=> '#28272e',
					'extra_bd_color'	=> '#464646',
					'extra_bd_hover'	=> '#4a4a4a',
					'extra_text'		=> '#a6a6a6',
					'extra_light'		=> '#5f5f5f',
					'extra_dark'		=> '#ffffff',
					'extra_link'		=> '#ffaa5f',
					'extra_hover'		=> '#fe7259',
					'extra_link2'		=> '#80d572',
					'extra_hover2'		=> '#8be77c',
					'extra_link3'		=> '#ddb837',
					'extra_hover3'		=> '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'	=> '#3b515e',
					'input_bg_hover'	=> '#3b515e',
					'input_bd_color'	=> '#3b515e',
					'input_bd_hover'	=> '#3b515e',
					'input_text'		=> '#ffffff',
					'input_light'		=> '#ffffff',
					'input_dark'		=> '#ffffff',
					
					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color'	=> '#e36650',
					'inverse_bd_hover'	=> '#cb5b47',
					'inverse_text'		=> '#1d1d1d',
					'inverse_light'		=> '#5f5f5f',
					'inverse_dark'		=> '#000000',
					'inverse_link'		=> '#ffffff',
					'inverse_hover'		=> '#1d1d1d'
				)
			)
		
		));
		
		// Simple schemes substitution
		gardis_storage_set('schemes_simple', array(
			// Main color	// Slave elements and it's darkness koef.
			'text_link'		=> array('alter_hover' => 1,	'extra_link' => 1, 'inverse_bd_color' => 0.85, 'inverse_bd_hover' => 0.7),
			'text_hover'	=> array('alter_link' => 1,		'extra_hover' => 1),
			'text_link2'	=> array('alter_hover2' => 1,	'extra_link2' => 1),
			'text_hover2'	=> array('alter_link2' => 1,	'extra_hover2' => 1),
			'text_link3'	=> array('alter_hover3' => 1,	'extra_link3' => 1),
			'text_hover3'	=> array('alter_link3' => 1,	'extra_hover3' => 1)
		));
	}
}

			
// Additional (calculated) theme-specific colors
// Attention! Don't forget setup custom colors also in the theme.customizer.color-scheme.js
if (!function_exists('gardis_customizer_add_theme_colors')) {
	function gardis_customizer_add_theme_colors($colors) {
		if (substr($colors['text'], 0, 1) == '#') {
			$colors['bg_color_0']  = gardis_hex2rgba( $colors['bg_color'], 0 );
			$colors['bg_color_02']  = gardis_hex2rgba( $colors['bg_color'], 0.2 );
			$colors['bg_color_04']  = gardis_hex2rgba( $colors['bg_color'], 0.4 );
			$colors['bg_color_05']  = gardis_hex2rgba( $colors['bg_color'], 0.5 );
			$colors['bg_color_06']  = gardis_hex2rgba( $colors['bg_color'], 0.6 );
			$colors['bg_color_07']  = gardis_hex2rgba( $colors['bg_color'], 0.7 );
			$colors['bg_color_08']  = gardis_hex2rgba( $colors['bg_color'], 0.8 );
			$colors['bg_color_09']  = gardis_hex2rgba( $colors['bg_color'], 0.9 );
			$colors['alter_bg_color_07']  = gardis_hex2rgba( $colors['alter_bg_color'], 0.7 );
			$colors['alter_bg_color_04']  = gardis_hex2rgba( $colors['alter_bg_color'], 0.4 );
			$colors['alter_bg_color_02']  = gardis_hex2rgba( $colors['alter_bg_color'], 0.2 );
			$colors['alter_bd_color_02']  = gardis_hex2rgba( $colors['alter_bd_color'], 0.2 );
			$colors['extra_bg_color_07']  = gardis_hex2rgba( $colors['extra_bg_color'], 0.7 );
			$colors['text_dark_01']  = gardis_hex2rgba( $colors['text_dark'], 0.1 );
			$colors['text_dark_02']  = gardis_hex2rgba( $colors['text_dark'], 0.2 );
			$colors['text_dark_04']  = gardis_hex2rgba( $colors['text_dark'], 0.4 );
			$colors['text_dark_05']  = gardis_hex2rgba( $colors['text_dark'], 0.5 );
			$colors['text_dark_06']  = gardis_hex2rgba( $colors['text_dark'], 0.6 );
			$colors['text_dark_07']  = gardis_hex2rgba( $colors['text_dark'], 0.7 );
			$colors['text_link_02']  = gardis_hex2rgba( $colors['text_link'], 0.2 );
			$colors['text_link_07']  = gardis_hex2rgba( $colors['text_link'], 0.7 );
			$colors['text_link_08']  = gardis_hex2rgba( $colors['text_link'], 0.8 );
			$colors['inverse_link_07']  = gardis_hex2rgba( $colors['inverse_link'], 0.7 );
			$colors['inverse_dark_09']  = gardis_hex2rgba( $colors['inverse_dark'], 0.9 );
			$colors['text_link_blend'] = gardis_hsb2hex(gardis_hex2hsb( $colors['text_link'], 2, -5, 5 ));
			$colors['alter_link_blend'] = gardis_hsb2hex(gardis_hex2hsb( $colors['alter_link'], 2, -5, 5 ));
		} else {
			$colors['bg_color_0'] = '{{ data.bg_color_0 }}';
			$colors['bg_color_02'] = '{{ data.bg_color_02 }}';
			$colors['bg_color_07'] = '{{ data.bg_color_07 }}';
			$colors['bg_color_08'] = '{{ data.bg_color_08 }}';
			$colors['bg_color_09'] = '{{ data.bg_color_09 }}';
			$colors['alter_bg_color_07'] = '{{ data.alter_bg_color_07 }}';
			$colors['alter_bg_color_04'] = '{{ data.alter_bg_color_04 }}';
			$colors['alter_bg_color_02'] = '{{ data.alter_bg_color_02 }}';
			$colors['alter_bd_color_02'] = '{{ data.alter_bd_color_02 }}';
			$colors['extra_bg_color_07'] = '{{ data.extra_bg_color_07 }}';
			$colors['text_dark_07'] = '{{ data.text_dark_07 }}';
			$colors['text_link_02'] = '{{ data.text_link_02 }}';
			$colors['text_link_07'] = '{{ data.text_link_07 }}';
			$colors['text_link_blend'] = '{{ data.text_link_blend }}';
			$colors['alter_link_blend'] = '{{ data.alter_link_blend }}';
		}
		return $colors;
	}
}


			
// Additional theme-specific fonts rules
// Attention! Don't forget setup fonts rules also in the theme.customizer.color-scheme.js
if (!function_exists('gardis_customizer_add_theme_fonts')) {
	function gardis_customizer_add_theme_fonts($fonts) {
		$rez = array();	
		foreach ($fonts as $tag => $font) {

			if (substr($font['font-family'], 0, 2) != '{{') {
				$rez[$tag.'_font-family'] 		= !empty($font['font-family']) && !gardis_is_inherit($font['font-family'])
														? 'font-family:' . trim($font['font-family']) . ';' 
														: '';
				$rez[$tag.'_font-size'] 		= !empty($font['font-size']) && !gardis_is_inherit($font['font-size'])
														? 'font-size:' . gardis_prepare_css_value($font['font-size']) . ";"
														: '';
				$rez[$tag.'_line-height'] 		= !empty($font['line-height']) && !gardis_is_inherit($font['line-height'])
														? 'line-height:' . trim($font['line-height']) . ";"
														: '';
				$rez[$tag.'_font-weight'] 		= !empty($font['font-weight']) && !gardis_is_inherit($font['font-weight'])
														? 'font-weight:' . trim($font['font-weight']) . ";"
														: '';
				$rez[$tag.'_font-style'] 		= !empty($font['font-style']) && !gardis_is_inherit($font['font-style'])
														? 'font-style:' . trim($font['font-style']) . ";"
														: '';
				$rez[$tag.'_text-decoration'] 	= !empty($font['text-decoration']) && !gardis_is_inherit($font['text-decoration'])
														? 'text-decoration:' . trim($font['text-decoration']) . ";"
														: '';
				$rez[$tag.'_text-transform'] 	= !empty($font['text-transform']) && !gardis_is_inherit($font['text-transform'])
														? 'text-transform:' . trim($font['text-transform']) . ";"
														: '';
				$rez[$tag.'_letter-spacing'] 	= !empty($font['letter-spacing']) && !gardis_is_inherit($font['letter-spacing'])
														? 'letter-spacing:' . trim($font['letter-spacing']) . ";"
														: '';
				$rez[$tag.'_margin-top'] 		= !empty($font['margin-top']) && !gardis_is_inherit($font['margin-top'])
														? 'margin-top:' . gardis_prepare_css_value($font['margin-top']) . ";"
														: '';
				$rez[$tag.'_margin-bottom'] 	= !empty($font['margin-bottom']) && !gardis_is_inherit($font['margin-bottom'])
														? 'margin-bottom:' . gardis_prepare_css_value($font['margin-bottom']) . ";"
														: '';
			} else {
				$rez[$tag.'_font-family']		= '{{ data["'.$tag.'_font-family"] }}';
				$rez[$tag.'_font-size']			= '{{ data["'.$tag.'_font-size"] }}';
				$rez[$tag.'_line-height']		= '{{ data["'.$tag.'_line-height"] }}';
				$rez[$tag.'_font-weight']		= '{{ data["'.$tag.'_font-weight"] }}';
				$rez[$tag.'_font-style']		= '{{ data["'.$tag.'_font-style"] }}';
				$rez[$tag.'_text-decoration']	= '{{ data["'.$tag.'_text-decoration"] }}';
				$rez[$tag.'_text-transform']	= '{{ data["'.$tag.'_text-transform"] }}';
				$rez[$tag.'_letter-spacing']	= '{{ data["'.$tag.'_letter-spacing"] }}';
				$rez[$tag.'_margin-top']		= '{{ data["'.$tag.'_margin-top"] }}';
				$rez[$tag.'_margin-bottom']		= '{{ data["'.$tag.'_margin-bottom"] }}';
			}
		}
		return $rez;
	}
}




//-------------------------------------------------------
//-- Thumb sizes
//-------------------------------------------------------

if ( !function_exists('gardis_customizer_theme_setup') ) {
	add_action( 'after_setup_theme', 'gardis_customizer_theme_setup' );
	function gardis_customizer_theme_setup() {

		// Enable support for Post Thumbnails
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size(370, 0, false);
		
		// Add thumb sizes
		// ATTENTION! If you change list below - check filter's names in the 'trx_addons_filter_get_thumb_size' hook
		$thumb_sizes = apply_filters('gardis_filter_add_thumb_sizes', array(
			'gardis-thumb-huge'		=> array(1170, 658, true),
			'gardis-thumb-big' 		=> array( 770, 380, true),
			'gardis-thumb-med' 		=> array( 370, 227, true),
			'gardis-thumb-square' 		=> array( 370, 370, true),
			'gardis-thumb-tiny' 		=> array(  180,  180, true),
			'gardis-thumb-masonry-big' => array( 760,   0, false),		// Only downscale, not crop
			'gardis-thumb-masonry'		=> array( 370,   0, false),		// Only downscale, not crop
			)
		);
		$mult = gardis_get_theme_option('retina_ready', 1);
		if ($mult > 1) $GLOBALS['content_width'] = apply_filters( 'gardis_filter_content_width', 1170*$mult);
		foreach ($thumb_sizes as $k=>$v) {
			// Add Original dimensions
			add_image_size( $k, $v[0], $v[1], $v[2]);
			// Add Retina dimensions
			if ($mult > 1) add_image_size( $k.'-@retina', $v[0]*$mult, $v[1]*$mult, $v[2]);
		}

	}
}

if ( !function_exists('gardis_customizer_image_sizes') ) {
	add_filter( 'image_size_names_choose', 'gardis_customizer_image_sizes' );
	function gardis_customizer_image_sizes( $sizes ) {
		$thumb_sizes = apply_filters('gardis_filter_add_thumb_sizes', array(
			'gardis-thumb-huge'		=> esc_html__( 'Huge image', 'gardis' ),
			'gardis-thumb-big'			=> esc_html__( 'Large image', 'gardis' ),
			'gardis-thumb-med'			=> esc_html__( 'Medium image', 'gardis' ),
			'gardis-thumb-tiny'		=> esc_html__( 'Small square avatar', 'gardis' ),
			'gardis-thumb-masonry-big'	=> esc_html__( 'Masonry Large (scaled)', 'gardis' ),
			'gardis-thumb-masonry'		=> esc_html__( 'Masonry (scaled)', 'gardis' ),
			)
		);
		$mult = gardis_get_theme_option('retina_ready', 1);
		foreach($thumb_sizes as $k=>$v) {
			$sizes[$k] = $v;
			if ($mult > 1) $sizes[$k.'-@retina'] = $v.' '.esc_html__('@2x', 'gardis' );
		}
		return $sizes;
	}
}

// Remove some thumb-sizes from the ThemeREX Addons list
if ( !function_exists( 'gardis_customizer_trx_addons_add_thumb_sizes' ) ) {
	add_filter( 'trx_addons_filter_add_thumb_sizes', 'gardis_customizer_trx_addons_add_thumb_sizes');
	function gardis_customizer_trx_addons_add_thumb_sizes($list=array()) {
		if (is_array($list)) {
			foreach ($list as $k=>$v) {
				if (in_array($k, array(
								'trx_addons-thumb-huge',
								'trx_addons-thumb-big',
								'trx_addons-thumb-medium',
								'trx_addons-thumb-tiny',
								'trx_addons-thumb-masonry-big',
								'trx_addons-thumb-masonry',
								)
							)
						) unset($list[$k]);
			}
		}
		return $list;
	}
}

// and replace removed styles with theme-specific thumb size
if ( !function_exists( 'gardis_customizer_trx_addons_get_thumb_size' ) ) {
	add_filter( 'trx_addons_filter_get_thumb_size', 'gardis_customizer_trx_addons_get_thumb_size');
	function gardis_customizer_trx_addons_get_thumb_size($thumb_size='') {
		return str_replace(array(
							'trx_addons-thumb-huge',
							'trx_addons-thumb-huge-@retina',
							'trx_addons-thumb-big',
							'trx_addons-thumb-big-@retina',
							'trx_addons-thumb-medium',
							'trx_addons-thumb-medium-@retina',
            'trx_addons-thumb-square',
            'trx_addons-thumb-square-@retina',
							'trx_addons-thumb-tiny',
							'trx_addons-thumb-tiny-@retina',
							'trx_addons-thumb-masonry-big',
							'trx_addons-thumb-masonry-big-@retina',
							'trx_addons-thumb-masonry',
							'trx_addons-thumb-masonry-@retina',
							),
							array(
							'gardis-thumb-huge',
							'gardis-thumb-huge-@retina',
							'gardis-thumb-big',
							'gardis-thumb-big-@retina',
							'gardis-thumb-med',
							'gardis-thumb-med-@retina',
                                'gardis-thumb-square',
                                'gardis-thumb-square-@retina',
							'gardis-thumb-tiny',
							'gardis-thumb-tiny-@retina',
							'gardis-thumb-masonry-big',
							'gardis-thumb-masonry-big-@retina',
							'gardis-thumb-masonry',
							'gardis-thumb-masonry-@retina',
							),
							$thumb_size);
	}
}




//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( !function_exists( 'gardis_importer_set_options' ) ) {
	add_filter( 'trx_addons_filter_importer_options', 'gardis_importer_set_options', 9 );
	function gardis_importer_set_options($options=array()) {
		if (is_array($options)) {
			// Save or not installer's messages to the log-file
			$options['debug'] = false;
			// Prepare demo data
			$options['demo_url'] = esc_url(gardis_get_protocol() . '://demofiles.ancorathemes.com/gardis/');
			// Required plugins
			$options['required_plugins'] = array_keys(gardis_storage_get('required_plugins'));
			// Set number of thumbnails to regenerate when its imported (if demo data was zipped without cropped images)
			// Set 0 to prevent regenerate thumbnails (if demo data archive is already contain cropped images)
			$options['regenerate_thumbnails'] = 3;
			// Default demo
			$options['files']['default']['title'] = esc_html__('Gardis Demo', 'gardis');
			$options['files']['default']['domain_dev'] = esc_url('http://gardis.dv.ancorathemes.com');		// Developers domain
			$options['files']['default']['domain_demo']= esc_url('http://gardis.ancorathemes.com');		// Demo-site domain
			// Banners
			$options['banners'] = array(
									array(
										'image' => gardis_get_file_url('theme-specific/theme.about/images/frontpage.png'),
										'title' => esc_html__('Front page Builder', 'gardis'),
										'content' => wp_kses(__('Create your Frontpage right in WordPress Customizer! To do this, you will not need neither the WPBakery Page Builder nor any other Builder. Just turn on/off sections, and fill them with content and decorate to your liking', 'gardis'), 'gardis_kses_content'),
										'link_url' => esc_url('//www.youtube.com/watch?v=VT0AUbMl_KA'),
										'link_caption' => esc_html__('More about Frontpage Builder', 'gardis'),
										'duration' => 20
										),
									array(
										'image' => gardis_get_file_url('theme-specific/theme.about/images/layouts.png'),
										'title' => esc_html__('Custom layouts', 'gardis'),
										'content' => wp_kses(__('Forget about problems with customization of header or footer! You can edit any of layout without any changes in CSS or HTML directly in Visual Builder. Moreover - you can easily create your own headers and footers and use them along with built-in', 'gardis'), 'gardis_kses_content'),
										'link_url' => esc_url('//www.youtube.com/watch?v=pYhdFVLd7y4'),
										'link_caption' => esc_html__('More about Custom Layouts', 'gardis'),
										'duration' => 20
										),
									array(
										'image' => gardis_get_file_url('theme-specific/theme.about/images/documentation.png'),
										'title' => esc_html__('Read full documentation', 'gardis'),
										'content' => wp_kses(__('Need more details? Please check our full online documentation for detailed information on how to use Gardis', 'gardis'), 'gardis_kses_content'),
										'link_url' => esc_url(gardis_storage_get('theme_doc_url')),
										'link_caption' => esc_html__('Online documentation', 'gardis'),
										'duration' => 15
										),
									array(
										'image' => gardis_get_file_url('theme-specific/theme.about/images/video-tutorials.png'),
										'title' => esc_html__('Video tutorials', 'gardis'),
										'content' => wp_kses(__('No time for reading documentation? Check out our video tutorials and learn how to customize Gardis in detail.', 'gardis'), 'gardis_kses_content'),
										'link_url' => esc_url(gardis_storage_get('theme_video_url')),
										'link_caption' => esc_html__('Video tutorials', 'gardis'),
										'duration' => 15
										),
									array(
										'image' => gardis_get_file_url('theme-specific/theme.about/images/studio.jpg'),
										'title' => esc_html__('Website Customization', 'gardis'),
										'content' => wp_kses(__('We can make a website based on this theme for a very fair price.
We can implement any extra functional: translate your website, WPML implementation and many other customization accroding to your request.', 'gardis'), 'gardis_kses_content'),
										'link_url' => esc_url('//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themedash'),
										'link_caption' => esc_html__('Contact us', 'gardis'),
										'duration' => 25
										)
									);
		}
		return $options;
	}
}




// -----------------------------------------------------------------
// -- Theme options for customizer
// -----------------------------------------------------------------
if (!function_exists('gardis_create_theme_options')) {

	function gardis_create_theme_options() {

		// Message about options override. 
		// Attention! Not need esc_html() here, because this message put in wp_kses_data() below
		$msg_override = wp_kses_data(__('<b>Attention!</b> Some of these options can be overridden in the following sections (Blog, Plugins settings, etc.) or in the settings of individual pages', 'gardis'));

		gardis_storage_set('options', array(
		
			// 'Logo & Site Identity'
			'title_tagline' => array(
				"title" => esc_html__('Logo & Site Identity', 'gardis'),
				"desc" => '',
				"priority" => 10,
				"type" => "section"
				),
			'logo_info' => array(
				"title" => esc_html__('Logo in the header', 'gardis'),
				"desc" => '',
				"priority" => 20,
				"type" => "info",
				),
			'logo_text' => array(
				"title" => esc_html__('Use Site Name as Logo', 'gardis'),
				"desc" => wp_kses_data( __('Use the site title and tagline as a text logo if no image is selected', 'gardis') ),
				"class" => "gardis_column-1_2 gardis_new_row",
				"priority" => 30,
				"std" => 1,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'logo_retina_enabled' => array(
				"title" => esc_html__('Allow retina display logo', 'gardis'),
				"desc" => wp_kses_data( __('Show fields to select logo images for Retina display', 'gardis') ),
				"class" => "gardis_column-1_2",
				"priority" => 40,
				"refresh" => false,
				"std" => 0,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'logo_max_height' => array(
				"title" => esc_html__('Logo max. height', 'gardis'),
				"desc" => wp_kses_data( __("Max. height of the logo image (in pixels). Maximum size of logo depends on the actual size of the picture", 'gardis') ),
				"std" => 80,
				"min" => 20,
				"max" => 160,
				"step" => 1,
				"refresh" => false,
				"type" => GARDIS_THEME_FREE ? "hidden" : "slider"
				),
			// Parameter 'logo' was replaced with standard WordPress 'custom_logo'
			'logo_retina' => array(
				"title" => esc_html__('Logo for Retina', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'gardis') ),
				"class" => "gardis_column-1_2",
				"priority" => 70,
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "image"
				),
			'logo_mobile_header' => array(
				"title" => esc_html__('Logo for the mobile header', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the mobile header (if enabled in the section "Header - Header mobile"', 'gardis') ),
				"class" => "gardis_column-1_2 gardis_new_row",
				"std" => '',
				"type" => "image"
				),
			'logo_mobile_header_retina' => array(
				"title" => esc_html__('Logo for the mobile header for Retina', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'gardis') ),
				"class" => "gardis_column-1_2",
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "image"
				),
			'logo_mobile' => array(
				"title" => esc_html__('Logo mobile', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the mobile menu', 'gardis') ),
				"class" => "gardis_column-1_2 gardis_new_row",
				"std" => '',
				"type" => "image"
				),
			'logo_mobile_retina' => array(
				"title" => esc_html__('Logo mobile for Retina', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'gardis') ),
				"class" => "gardis_column-1_2",
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "image"
				),
			'logo_side' => array(
				"title" => esc_html__('Logo side', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu', 'gardis') ),
				"class" => "gardis_column-1_2 gardis_new_row",
				"std" => '',
				"type" => "image"
				),
			'logo_side_retina' => array(
				"title" => esc_html__('Logo side for Retina', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu on Retina displays (if empty - use default logo from the field above)', 'gardis') ),
				"class" => "gardis_column-1_2",
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "image"
				),
			
		
		
			// 'General settings'
			'general' => array(
				"title" => esc_html__('General Settings', 'gardis'),
				"desc" => wp_kses_data( $msg_override ),
				"priority" => 20,
				"type" => "section",
				),

			'general_layout_info' => array(
				"title" => esc_html__('Layout', 'gardis'),
				"desc" => '',
				"type" => "info",
				),
			'body_style' => array(
				"title" => esc_html__('Body style', 'gardis'),
				"desc" => wp_kses_data( __('Select width of the body content', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'gardis')
				),
				"refresh" => false,
				"std" => 'wide',
				"options" => gardis_get_list_body_styles(),
				"type" => "select"
				),
			'boxed_bg_image' => array(
				"title" => esc_html__('Boxed bg image', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload image, used as background in the boxed body', 'gardis') ),
				"dependency" => array(
					'body_style' => array('boxed')
				),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'gardis')
				),
				"std" => '',
				"hidden" => true,
				"type" => "image"
				),
			'remove_margins' => array(
				"title" => esc_html__('Remove margins', 'gardis'),
				"desc" => wp_kses_data( __('Remove margins above and below the content area', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'gardis')
				),
				"refresh" => false,
				"std" => 0,
				"type" => "checkbox"
				),

			'general_sidebar_info' => array(
				"title" => esc_html__('Sidebar', 'gardis'),
				"desc" => '',
				"type" => "info",
				),
			'sidebar_position' => array(
				"title" => esc_html__('Sidebar position', 'gardis'),
				"desc" => wp_kses_data( __('Select position to show sidebar', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'gardis')
				),
				"std" => 'right',
				"options" => array(),
				"type" => "switch"
				),
			'sidebar_widgets' => array(
				"title" => esc_html__('Sidebar widgets', 'gardis'),
				"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'gardis')
				),
				"dependency" => array(
					'sidebar_position' => array('left', 'right')
				),
				"std" => 'sidebar_widgets',
				"options" => array(),
				"type" => "select"
				),
			'expand_content' => array(
				"title" => esc_html__('Expand content', 'gardis'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'gardis') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),


			'general_widgets_info' => array(
				"title" => esc_html__('Additional widgets', 'gardis'),
				"desc" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "info",
				),
			'widgets_above_page' => array(
				"title" => esc_html__('Widgets at the top of the page', 'gardis'),
				"desc" => wp_kses_data( __('Select widgets to show at the top of the page (above content and sidebar)', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'gardis')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "select"
				),
			'widgets_above_content' => array(
				"title" => esc_html__('Widgets above the content', 'gardis'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'gardis')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "select"
				),
			'widgets_below_content' => array(
				"title" => esc_html__('Widgets below the content', 'gardis'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'gardis')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "select"
				),
			'widgets_below_page' => array(
				"title" => esc_html__('Widgets at the bottom of the page', 'gardis'),
				"desc" => wp_kses_data( __('Select widgets to show at the bottom of the page (below content and sidebar)', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'gardis')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "select"
				),

			'general_effects_info' => array(
				"title" => esc_html__('Design & Effects', 'gardis'),
				"desc" => '',
				"type" => "info",
				),
			'border_radius' => array(
				"title" => esc_html__('Border radius', 'gardis'),
				"desc" => wp_kses_data( __('Specify the border radius of the form fields and buttons in pixels or other valid CSS units', 'gardis') ),
				"std" => 0,
				"type" => "text"
				),

			'general_misc_info' => array(
				"title" => esc_html__('Miscellaneous', 'gardis'),
				"desc" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "info",
				),
			'seo_snippets' => array(
				"title" => esc_html__('SEO snippets', 'gardis'),
				"desc" => wp_kses_data( __('Add structured data markup to the single posts and pages', 'gardis') ),
				"std" => 0,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'privacy_text' => array(
				"title" => esc_html__("Text with Privacy Policy link", 'gardis'),
				"desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'gardis') ),
				"std"   => wp_kses( __( 'I agree that my submitted data is being collected and stored.', 'gardis'), 'gardis_kses_content' ),
				"type"  => "text"
			),
		
		
			// 'Header'
			'header' => array(
				"title" => esc_html__('Header', 'gardis'),
				"desc" => wp_kses_data( $msg_override ),
				"priority" => 30,
				"type" => "section"
				),

			'header_style_info' => array(
				"title" => esc_html__('Header style', 'gardis'),
				"desc" => '',
				"type" => "info"
				),
			'header_type' => array(
				"title" => esc_html__('Header style', 'gardis'),
				"desc" => wp_kses_data( __('Choose whether to use the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"std" => 'default',
				"options" => gardis_get_list_header_footer_types(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
				),
			'header_style' => array(
				"title" => esc_html__('Select custom layout', 'gardis'),
				"desc" => wp_kses_data( __('Select custom header from Layouts Builder', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"dependency" => array(
					'header_type' => array('custom')
				),
				"std" => GARDIS_THEME_FREE ? 'header-default' : 'header-default',
				"options" => array(),
				"type" => "select"
				),
			'header_position' => array(
				"title" => esc_html__('Header position', 'gardis'),
				"desc" => wp_kses_data( __('Select position to display the site header', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"std" => 'default',
				"options" => array(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
				),
			'header_fullheight' => array(
				"title" => esc_html__('Header fullheight', 'gardis'),
				"desc" => wp_kses_data( __("Enlarge header area to fill whole screen. Used only if header have a background image", 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"std" => 0,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_zoom' => array(
				"title" => esc_html__('Header zoom', 'gardis'),
				"desc" => wp_kses_data( __("Zoom the header title. 1 - original size", 'gardis') ),
				"std" => 1,
				"min" => 0.3,
				"max" => 2,
				"step" => 0.1,
				"refresh" => false,
				"type" => GARDIS_THEME_FREE ? "hidden" : "slider"
				),
			'header_wide' => array(
				"title" => esc_html__('Header fullwide', 'gardis'),
				"desc" => wp_kses_data( __('Do you want to stretch the header widgets area to the entire window width?', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"dependency" => array(
					'header_type' => array('default')
				),
				"std" => 1,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),

			'header_widgets_info' => array(
				"title" => esc_html__('Header widgets', 'gardis'),
				"desc" => wp_kses_data( __('Here you can place a widget slider, advertising banners, etc.', 'gardis') ),
				"type" => "info"
				),
			'header_widgets' => array(
				"title" => esc_html__('Header widgets', 'gardis'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on each page', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis'),
					"desc" => wp_kses_data( __('Select set of widgets to show in the header on this page', 'gardis') ),
				),
				"std" => 'hide',
				"options" => array(),
				"type" => "select"
				),
			'header_columns' => array(
				"title" => esc_html__('Header columns', 'gardis'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the Header. If 0 - autodetect by the widgets count', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"dependency" => array(
					'header_type' => array('default'),
					'header_widgets' => array('^hide')
				),
				"std" => 0,
				"options" => gardis_get_list_range(0,6),
				"type" => "select"
				),

			'menu_info' => array(
				"title" => esc_html__('Main menu', 'gardis'),
				"desc" => wp_kses_data( __('Select main menu style, position, color scheme and other parameters', 'gardis') ),
				"type" => GARDIS_THEME_FREE ? "hidden" : "info"
				),
			'menu_style' => array(
				"title" => esc_html__('Menu position', 'gardis'),
				"desc" => wp_kses_data( __('Select position of the main menu', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"std" => 'top',
				"options" => array(
					'top'	=> esc_html__('Top',	'gardis'),
					'left'	=> esc_html__('Left',	'gardis'),
					'right'	=> esc_html__('Right',	'gardis')
				),
				"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
				),
			'menu_side_stretch' => array(
				"title" => esc_html__('Stretch sidemenu', 'gardis'),
				"desc" => wp_kses_data( __('Stretch sidemenu to window height (if menu items number >= 5)', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 0,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'menu_side_icons' => array(
				"title" => esc_html__('Iconed sidemenu', 'gardis'),
				"desc" => wp_kses_data( __('Get icons from anchors and display it in the sidemenu or mark sidemenu items with simple dots', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'gardis')
				),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'menu_mobile_fullscreen' => array(
				"title" => esc_html__('Mobile menu fullscreen', 'gardis'),
				"desc" => wp_kses_data( __('Display mobile and side menus on full screen (if checked) or slide narrow menu from the left or from the right side (if not checked)', 'gardis') ),
				"std" => 1,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),

			'header_image_info' => array(
				"title" => esc_html__('Header image', 'gardis'),
				"desc" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "info"
				),
			'header_image_override' => array(
				"title" => esc_html__('Header image override', 'gardis'),
				"desc" => wp_kses_data( __("Allow override the header image with the page's/post's/product's/etc. featured image", 'gardis') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'gardis')
				),
				"std" => 0,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),

			'header_mobile_info' => array(
				"title" => esc_html__('Mobile header', 'gardis'),
				"desc" => wp_kses_data( __("Configure the mobile version of the header", 'gardis') ),
				"priority" => 500,
				"type" => GARDIS_THEME_FREE ? "hidden" : "info"
				),
			'header_mobile_enabled' => array(
				"title" => esc_html__('Enable the mobile header', 'gardis'),
				"desc" => wp_kses_data( __("Use the mobile version of the header (if checked) or relayout the current header on mobile devices", 'gardis') ),
				"std" => 0,
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_mobile_additional_info' => array(
				"title" => esc_html__('Additional info', 'gardis'),
				"desc" => wp_kses_data( __('Additional info to show at the top of the mobile header', 'gardis') ),
				"std" => '',
				"dependency" => array(
					'header_mobile_enabled' => array(1)
				),
				"refresh" => false,
				"teeny" => false,
				"rows" => 20,
				"type" => GARDIS_THEME_FREE ? "hidden" : "text_editor"
				),
			'header_mobile_hide_info' => array(
				"title" => esc_html__('Hide additional info', 'gardis'),
				"std" => 0,
				"dependency" => array(
					'header_mobile_enabled' => array(1)
				),
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_mobile_hide_logo' => array(
				"title" => esc_html__('Hide logo', 'gardis'),
				"std" => 0,
				"dependency" => array(
					'header_mobile_enabled' => array(1)
				),
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_mobile_hide_login' => array(
				"title" => esc_html__('Hide login/logout', 'gardis'),
				"std" => 0,
				"dependency" => array(
					'header_mobile_enabled' => array(1)
				),
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_mobile_hide_search' => array(
				"title" => esc_html__('Hide search', 'gardis'),
				"std" => 0,
				"dependency" => array(
					'header_mobile_enabled' => array(1)
				),
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_mobile_hide_cart' => array(
				"title" => esc_html__('Hide cart', 'gardis'),
				"std" => 0,
				"dependency" => array(
					'header_mobile_enabled' => array(1)
				),
				"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
				),


		
			// 'Footer'
			'footer' => array(
				"title" => esc_html__('Footer', 'gardis'),
				"desc" => wp_kses_data( $msg_override ),
				"priority" => 50,
				"type" => "section"
				),
			'footer_type' => array(
				"title" => esc_html__('Footer style', 'gardis'),
				"desc" => wp_kses_data( __('Choose whether to use the default footer or footer Layouts (available only if the ThemeREX Addons is activated)', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'gardis')
				),
				"std" => 'default',
				"options" => gardis_get_list_header_footer_types(),
				"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
				),
			'footer_style' => array(
				"title" => esc_html__('Select custom layout', 'gardis'),
				"desc" => wp_kses_data( __('Select custom footer from Layouts Builder', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'gardis')
				),
				"dependency" => array(
					'footer_type' => array('custom')
				),
				"std" => GARDIS_THEME_FREE ? 'footer-default' : 'footer-default',
				"options" => array(),
				"type" => "select"
				),
			'footer_widgets' => array(
				"title" => esc_html__('Footer widgets', 'gardis'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'gardis')
				),
				"dependency" => array(
					'footer_type' => array('default')
				),
				"std" => 'footer_widgets',
				"options" => array(),
				"type" => "select"
				),
			'footer_columns' => array(
				"title" => esc_html__('Footer columns', 'gardis'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'gardis')
				),
				"dependency" => array(
					'footer_type' => array('default'),
					'footer_widgets' => array('^hide')
				),
				"std" => 0,
				"options" => gardis_get_list_range(0,6),
				"type" => "select"
				),
			'footer_wide' => array(
				"title" => esc_html__('Footer fullwide', 'gardis'),
				"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'gardis') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'gardis')
				),
				"dependency" => array(
					'footer_type' => array('default')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_in_footer' => array(
				"title" => esc_html__('Show logo', 'gardis'),
				"desc" => wp_kses_data( __('Show logo in the footer', 'gardis') ),
				'refresh' => false,
				"dependency" => array(
					'footer_type' => array('default')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_footer' => array(
				"title" => esc_html__('Logo for footer', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the footer', 'gardis') ),
				"dependency" => array(
					'footer_type' => array('default'),
					'logo_in_footer' => array(1)
				),
				"std" => '',
				"type" => "image"
				),
			'logo_footer_retina' => array(
				"title" => esc_html__('Logo for footer (Retina)', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload logo for the footer area used on Retina displays (if empty - use default logo from the field above)', 'gardis') ),
				"dependency" => array(
					'footer_type' => array('default'),
					'logo_in_footer' => array(1),
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "image"
				),
			'socials_in_footer' => array(
				"title" => esc_html__('Show social icons', 'gardis'),
				"desc" => wp_kses_data( __('Show social icons in the footer (under logo or footer widgets)', 'gardis') ),
				"dependency" => array(
					'footer_type' => array('default')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'copyright' => array(
				"title" => esc_html__('Copyright', 'gardis'),
				"desc" => wp_kses_data( __('Copyright text in the footer. Use {Y} to insert current year and press "Enter" to create a new line', 'gardis') ),
				"std" => esc_html__('AncoraThemes &copy; {Y}. All rights reserved.', 'gardis'),
				"dependency" => array(
					'footer_type' => array('default')
				),
				"refresh" => false,
				"type" => "textarea"
				),
			
		
		
			// 'Blog'
			'blog' => array(
				"title" => esc_html__('Blog', 'gardis'),
				"desc" => wp_kses_data( __('Options of the the blog archive', 'gardis') ),
				"priority" => 70,
				"type" => "panel",
				),
		
				// Blog - Posts page
				'blog_general' => array(
					"title" => esc_html__('Posts page', 'gardis'),
					"desc" => wp_kses_data( __('Style and components of the blog archive', 'gardis') ),
					"type" => "section",
					),
				'blog_general_info' => array(
					"title" => esc_html__('General settings', 'gardis'),
					"desc" => '',
					"type" => "info",
					),
				'blog_style' => array(
					"title" => esc_html__('Blog style', 'gardis'),
					"desc" => '',
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"std" => 'excerpt',
					"options" => array(),
					"type" => "select"
					),
				'first_post_large' => array(
					"title" => esc_html__('First post large', 'gardis'),
					"desc" => wp_kses_data( __('Make your first post stand out by making it bigger', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
						'blog_style' => array('classic', 'masonry')
					),
					"std" => 0,
					"type" => "checkbox"
					),
				"blog_content" => array( 
					"title" => esc_html__('Posts content', 'gardis'),
					"desc" => wp_kses_data( __("Display either post excerpts or the full post content", 'gardis') ),
					"std" => "excerpt",
					"dependency" => array(
						'blog_style' => array('excerpt')
					),
					"options" => array(
						'excerpt'	=> esc_html__('Excerpt',	'gardis'),
						'fullpost'	=> esc_html__('Full post',	'gardis')
					),
					"type" => "switch"
					),
				'excerpt_length' => array(
					"title" => esc_html__('Excerpt length', 'gardis'),
					"desc" => wp_kses_data( __("Length (in words) to generate excerpt from the post content. Attention! If the post excerpt is explicitly specified - it appears unchanged", 'gardis') ),
					"dependency" => array(
						'blog_style' => array('excerpt'),
						'blog_content' => array('excerpt')
					),
					"std" => 60,
					"type" => "text"
					),
				'blog_columns' => array(
					"title" => esc_html__('Blog columns', 'gardis'),
					"desc" => wp_kses_data( __('How many columns should be used in the blog archive (from 2 to 4)?', 'gardis') ),
					"std" => 2,
					"options" => gardis_get_list_range(2,4),
					"type" => "hidden"
					),
				'post_type' => array(
					"title" => esc_html__('Post type', 'gardis'),
					"desc" => wp_kses_data( __('Select post type to show in the blog archive', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"linked" => 'parent_cat',
					"refresh" => false,
					"hidden" => true,
					"std" => 'post',
					"options" => array(),
					"type" => "select"
					),
				'parent_cat' => array(
					"title" => esc_html__('Category to show', 'gardis'),
					"desc" => wp_kses_data( __('Select category to show in the blog archive', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"refresh" => false,
					"hidden" => true,
					"std" => '0',
					"options" => array(),
					"type" => "select"
					),
				'posts_per_page' => array(
					"title" => esc_html__('Posts per page', 'gardis'),
					"desc" => wp_kses_data( __('How many posts will be displayed on this page', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"hidden" => true,
					"std" => '',
					"type" => "text"
					),
				"blog_pagination" => array( 
					"title" => esc_html__('Pagination style', 'gardis'),
					"desc" => wp_kses_data( __('Show Older/Newest posts or Page numbers below the posts list', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"std" => "pages",
					"options" => array(
						'pages'	=> esc_html__("Page numbers", 'gardis'),
						'links'	=> esc_html__("Older/Newest", 'gardis'),
						'more'	=> esc_html__("Load more", 'gardis'),
						'infinite' => esc_html__("Infinite scroll", 'gardis')
					),
					"type" => "select"
					),
				'show_filters' => array(
					"title" => esc_html__('Show filters', 'gardis'),
					"desc" => wp_kses_data( __('Show categories as tabs to filter posts', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
						'blog_style' => array('portfolio', 'gallery')
					),
					"hidden" => true,
					"std" => 0,
					"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
					),
	
				'blog_sidebar_info' => array(
					"title" => esc_html__('Sidebar', 'gardis'),
					"desc" => '',
					"type" => "info",
					),
				'sidebar_position_blog' => array(
					"title" => esc_html__('Sidebar position', 'gardis'),
					"desc" => wp_kses_data( __('Select position to show sidebar', 'gardis') ),
					"std" => 'right',
					"options" => array(),
					"type" => "switch"
					),
				'sidebar_widgets_blog' => array(
					"title" => esc_html__('Sidebar widgets', 'gardis'),
					"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'gardis') ),
					"dependency" => array(
						'sidebar_position_blog' => array('left', 'right')
					),
					"std" => 'sidebar_widgets',
					"options" => array(),
					"type" => "select"
					),
				'expand_content_blog' => array(
					"title" => esc_html__('Expand content', 'gardis'),
					"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'gardis') ),
					"refresh" => false,
					"std" => 1,
					"type" => "checkbox"
					),
	
	
				'blog_widgets_info' => array(
					"title" => esc_html__('Additional widgets', 'gardis'),
					"desc" => '',
					"type" => GARDIS_THEME_FREE ? "hidden" : "info",
					),
				'widgets_above_page_blog' => array(
					"title" => esc_html__('Widgets at the top of the page', 'gardis'),
					"desc" => wp_kses_data( __('Select widgets to show at the top of the page (above content and sidebar)', 'gardis') ),
					"std" => 'hide',
					"options" => array(),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),
				'widgets_above_content_blog' => array(
					"title" => esc_html__('Widgets above the content', 'gardis'),
					"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'gardis') ),
					"std" => 'hide',
					"options" => array(),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),
				'widgets_below_content_blog' => array(
					"title" => esc_html__('Widgets below the content', 'gardis'),
					"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'gardis') ),
					"std" => 'hide',
					"options" => array(),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),
				'widgets_below_page_blog' => array(
					"title" => esc_html__('Widgets at the bottom of the page', 'gardis'),
					"desc" => wp_kses_data( __('Select widgets to show at the bottom of the page (below content and sidebar)', 'gardis') ),
					"std" => 'hide',
					"options" => array(),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),

				'blog_advanced_info' => array(
					"title" => esc_html__('Advanced settings', 'gardis'),
					"desc" => '',
					"type" => "info",
					),
				'no_image' => array(
					"title" => esc_html__('Image placeholder', 'gardis'),
					"desc" => wp_kses_data( __('Select or upload an image used as placeholder for posts without a featured image', 'gardis') ),
					"std" => '',
					"type" => "image"
					),
				'time_diff_before' => array(
					"title" => esc_html__('Easy Readable Date Format', 'gardis'),
					"desc" => wp_kses_data( __("For how many days to show the easy-readable date format (e.g. '3 days ago') instead of the standard publication date", 'gardis') ),
					"std" => 5,
					"type" => "text"
					),
				'sticky_style' => array(
					"title" => esc_html__('Sticky posts style', 'gardis'),
					"desc" => wp_kses_data( __('Select style of the sticky posts output', 'gardis') ),
					"std" => 'inherit',
					"options" => array(
						'inherit' => esc_html__('Decorated posts', 'gardis'),
						'columns' => esc_html__('Mini-cards',	'gardis')
					),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),
				"blog_animation" => array( 
					"title" => esc_html__('Animation for the posts', 'gardis'),
					"desc" => wp_kses_data( __('Select animation to show posts in the blog. Attention! Do not use any animation on pages with the "wheel to the anchor" behaviour (like a "Chess 2 columns")!', 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"std" => "none",
					"options" => array(),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),
				'meta_parts' => array(
					"title" => esc_html__('Post meta', 'gardis'),
					"desc" => wp_kses_data( __("If your blog page is created using the 'Blog archive' page template, set up the 'Post Meta' settings in the 'Theme Options' section of that page.", 'gardis') )
								. '<br>'
								. wp_kses_data( __("<b>Tip:</b> Drag items to change their order.", 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'author=1|date=1|categories=1|counters=1|share=0|edit=0',
					"options" => array(
						'categories' => esc_html__('Categories', 'gardis'),
						'date'		 => esc_html__('Post date', 'gardis'),
						'author'	 => esc_html__('Post author', 'gardis'),
						'counters'	 => esc_html__('Views, Likes and Comments', 'gardis'),
						'share'		 => esc_html__('Share links', 'gardis'),
						'edit'		 => esc_html__('Edit link', 'gardis')
					),
					"type" => GARDIS_THEME_FREE ? "hidden" : "checklist"
				),
				'counters' => array(
					"title" => esc_html__('Views, Likes and Comments', 'gardis'),
					"desc" => wp_kses_data( __("Likes and Views are available only if ThemeREX Addons is active", 'gardis') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'gardis')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'views=0|likes=0|comments=1',
					"options" => array(
						'views' => esc_html__('Views', 'gardis'),
						'likes' => esc_html__('Likes', 'gardis'),
						'comments' => esc_html__('Comments', 'gardis')
					),
					"type" => GARDIS_THEME_FREE ? "hidden" : "checklist"
				),

				
				// Blog - Single posts
				'blog_single' => array(
					"title" => esc_html__('Single posts', 'gardis'),
					"desc" => wp_kses_data( __('Settings of the single post', 'gardis') ),
					"type" => "section",
					),
				'hide_featured_on_single' => array(
					"title" => esc_html__('Hide featured image on the single post', 'gardis'),
					"desc" => wp_kses_data( __("Hide featured image on the single post's pages", 'gardis') ),
					"override" => array(
						'mode' => 'page,post',
						'section' => esc_html__('Content', 'gardis')
					),
					"std" => 0,
					"type" => "checkbox"
					),
				'hide_sidebar_on_single' => array(
					"title" => esc_html__('Hide sidebar on the single post', 'gardis'),
					"desc" => wp_kses_data( __("Hide sidebar on the single post's pages", 'gardis') ),
					"std" => 0,
					"type" => "checkbox"
					),
				'show_post_meta' => array(
					"title" => esc_html__('Show post meta', 'gardis'),
					"desc" => wp_kses_data( __("Display block with post's meta: date, categories, counters, etc.", 'gardis') ),
					"std" => 0,
					"type" => "checkbox"
					),
				'meta_parts_post' => array(
					"title" => esc_html__('Post meta', 'gardis'),
					"desc" => wp_kses_data( __("Meta parts for single posts.", 'gardis') ),
					"dependency" => array(
						'show_post_meta' => array(1)
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'categories=1|date=1|counters=1|author=0|share=0|edit=1',
					"options" => array(
						'categories' => esc_html__('Categories', 'gardis'),
						'date'		 => esc_html__('Post date', 'gardis'),
						'author'	 => esc_html__('Post author', 'gardis'),
						'counters'	 => esc_html__('Views, Likes and Comments', 'gardis'),
						'share'		 => esc_html__('Share links', 'gardis'),
						'edit'		 => esc_html__('Edit link', 'gardis')
					),
					"type" => GARDIS_THEME_FREE ? "hidden" : "checklist"
				),
				'counters_post' => array(
					"title" => esc_html__('Views, Likes and Comments', 'gardis'),
					"desc" => wp_kses_data( __("Likes and Views are available only if ThemeREX Addons is active", 'gardis') ),
					"dependency" => array(
						'show_post_meta' => array(1)
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'views=1|likes=1|comments=1',
					"options" => array(
						'views' => esc_html__('Views', 'gardis'),
						'likes' => esc_html__('Likes', 'gardis'),
						'comments' => esc_html__('Comments', 'gardis')
					),
					"type" => GARDIS_THEME_FREE ? "hidden" : "checklist"
				),
				'show_share_links' => array(
					"title" => esc_html__('Show share links', 'gardis'),
					"desc" => wp_kses_data( __("Display share links on the single post", 'gardis') ),
					"std" => 1,
					"type" => "checkbox"
					),
				'show_author_info' => array(
					"title" => esc_html__('Show author info', 'gardis'),
					"desc" => wp_kses_data( __("Display block with information about post's author", 'gardis') ),
					"std" => 1,
					"type" => "checkbox"
					),
				'blog_single_related_info' => array(
					"title" => esc_html__('Related posts', 'gardis'),
					"desc" => '',
					"type" => "info",
					),
				'show_related_posts' => array(
					"title" => esc_html__('Show related posts', 'gardis'),
					"desc" => wp_kses_data( __("Show section 'Related posts' on the single post's pages", 'gardis') ),
					"override" => array(
						'mode' => 'page,post',
						'section' => esc_html__('Content', 'gardis')
					),
					"std" => 0,
					"type" => "checkbox"
					),
				'related_posts' => array(
					"title" => esc_html__('Related posts', 'gardis'),
					"desc" => wp_kses_data( __('How many related posts should be displayed in the single post? If 0 - no related posts showed.', 'gardis') ),
					"dependency" => array(
						'show_related_posts' => array(1)
					),
					"std" => 2,
					"options" => gardis_get_list_range(1,9),
					"type" => GARDIS_THEME_FREE ? "hidden" : "select"
					),
				'related_columns' => array(
					"title" => esc_html__('Related columns', 'gardis'),
					"desc" => wp_kses_data( __('How many columns should be used to output related posts in the single page (from 2 to 4)?', 'gardis') ),
					"dependency" => array(
						'show_related_posts' => array(1)
					),
					"std" => 2,
					"options" => gardis_get_list_range(1,4),
					"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
					),
				'related_style' => array(
					"title" => esc_html__('Related posts style', 'gardis'),
					"desc" => wp_kses_data( __('Select style of the related posts output', 'gardis') ),
					"dependency" => array(
						'show_related_posts' => array(1)
					),
					"std" => 2,
					"options" => gardis_get_list_styles(1,2),
					"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
					),
			'blog_end' => array(
				"type" => "panel_end",
				),
			
		
		
			// 'Colors'
			'panel_colors' => array(
				"title" => esc_html__('Colors', 'gardis'),
				"desc" => '',
				"priority" => 300,
				"type" => "section"
				),

			'color_schemes_info' => array(
				"title" => esc_html__('Color schemes', 'gardis'),
				"desc" => wp_kses_data( __('Color schemes for various parts of the site. "Inherit" means that this block is used the Site color scheme (the first parameter)', 'gardis') ),
				"type" => "info",
				),
			'color_scheme' => array(
				"title" => esc_html__('Site Color Scheme', 'gardis'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'gardis')
				),
				"std" => 'default',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),
			'header_scheme' => array(
				"title" => esc_html__('Header Color Scheme', 'gardis'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'gardis')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),
			'menu_scheme' => array(
				"title" => esc_html__('Sidemenu Color Scheme', 'gardis'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'gardis')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
				),
			'sidebar_scheme' => array(
				"title" => esc_html__('Sidebar Color Scheme', 'gardis'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'gardis')
				),
				"std" => 'default',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),
			'footer_scheme' => array(
				"title" => esc_html__('Footer Color Scheme', 'gardis'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'gardis')
				),
				"std" => 'default',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),

			'color_scheme_editor_info' => array(
				"title" => esc_html__('Color scheme editor', 'gardis'),
				"desc" => wp_kses_data(__('Select color scheme to modify. Attention! Only those sections in the site will be changed which this scheme was assigned to', 'gardis') ),
				"type" => "info",
				),
			'scheme_storage' => array(
				"title" => esc_html__('Color scheme editor', 'gardis'),
				"desc" => '',
				"std" => '$gardis_get_scheme_storage',
				"refresh" => false,
				"colorpicker" => "tiny",
				"type" => "scheme_editor"
				),


			// 'Hidden'
			'media_title' => array(
				"title" => esc_html__('Media title', 'gardis'),
				"desc" => wp_kses_data( __('Used as title for the audio and video item in this post', 'gardis') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Content', 'gardis')
				),
				"hidden" => true,
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "text"
				),
			'media_author' => array(
				"title" => esc_html__('Media author', 'gardis'),
				"desc" => wp_kses_data( __('Used as author name for the audio and video item in this post', 'gardis') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Content', 'gardis')
				),
				"hidden" => true,
				"std" => '',
				"type" => GARDIS_THEME_FREE ? "hidden" : "text"
				),


			// Internal options.
			// Attention! Don't change any options in the section below!
			// Use huge priority to call render this elements after all options!
			'reset_options' => array(
				"title" => '',
				"desc" => '',
				"std" => '0',
				"priority" => 10000,
				"type" => "hidden",
				),

			'last_option' => array(		// Need to manually call action to include Tiny MCE scripts
				"title" => '',
				"desc" => '',
				"std" => 1,
				"type" => "hidden",
				),

		));


		// Prepare panel 'Fonts'
		$fonts = array(
		
			// 'Fonts'
			'fonts' => array(
				"title" => esc_html__('Typography', 'gardis'),
				"desc" => '',
				"priority" => 200,
				"type" => "panel"
				),

			// Fonts - Load_fonts
			'load_fonts' => array(
				"title" => esc_html__('Load fonts', 'gardis'),
				"desc" => wp_kses_data( __('Specify fonts to load when theme start. You can use them in the base theme elements: headers, text, menu, links, input fields, etc.', 'gardis') )
						. '<br>'
						. wp_kses_data( __('<b>Attention!</b> Press "Refresh" button to reload preview area after the all fonts are changed', 'gardis') ),
				"type" => "section"
				),
			'load_fonts_subset' => array(
				"title" => esc_html__('Google fonts subsets', 'gardis'),
				"desc" => wp_kses_data( __('Specify comma separated list of the subsets which will be load from Google fonts', 'gardis') )
						. '<br>'
						. wp_kses_data( __('Available subsets are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese', 'gardis') ),
				"class" => "gardis_column-1_3 gardis_new_row",
				"refresh" => false,
				"std" => '$gardis_get_load_fonts_subset',
				"type" => "text"
				)
		);

		for ($i=1; $i<=gardis_get_theme_setting('max_load_fonts'); $i++) {
			if (gardis_get_value_gp('page') != 'theme_options') {
				$fonts["load_fonts-{$i}-info"] = array(
					// Translators: Add font's number - 'Font 1', 'Font 2', etc
					"title" => esc_html(sprintf(esc_html__('Font %s', 'gardis'), $i)),
					"desc" => '',
					"type" => "info",
					);
			}
			$fonts["load_fonts-{$i}-name"] = array(
				"title" => esc_html__('Font name', 'gardis'),
				"desc" => '',
				"class" => "gardis_column-1_3 gardis_new_row",
				"refresh" => false,
				"std" => '$gardis_get_load_fonts_option',
				"type" => "text"
				);
			$fonts["load_fonts-{$i}-family"] = array(
				"title" => esc_html__('Font family', 'gardis'),
				"desc" => $i==1 
							? wp_kses_data( __('Select font family to use it if font above is not available', 'gardis') )
							: '',
				"class" => "gardis_column-1_3",
				"refresh" => false,
				"std" => '$gardis_get_load_fonts_option',
				"options" => array(
					'inherit' => esc_html__("Inherit", 'gardis'),
					'serif' => esc_html__('serif', 'gardis'),
					'sans-serif' => esc_html__('sans-serif', 'gardis'),
					'monospace' => esc_html__('monospace', 'gardis'),
					'cursive' => esc_html__('cursive', 'gardis'),
					'fantasy' => esc_html__('fantasy', 'gardis')
				),
				"type" => "select"
				);
			$fonts["load_fonts-{$i}-styles"] = array(
				"title" => esc_html__('Font styles', 'gardis'),
				"desc" => $i==1 
							? wp_kses_data( __('Font styles used only for the Google fonts. This is a comma separated list of the font weight and styles. For example: 400,400italic,700', 'gardis') )
								. '<br>'
								. wp_kses_data( __('<b>Attention!</b> Each weight and style increase download size! Specify only used weights and styles.', 'gardis') )
							: '',
				"class" => "gardis_column-1_3",
				"refresh" => false,
				"std" => '$gardis_get_load_fonts_option',
				"type" => "text"
				);
		}
		$fonts['load_fonts_end'] = array(
			"type" => "section_end"
			);

		// Fonts - H1..6, P, Info, Menu, etc.
		$theme_fonts = gardis_get_theme_fonts();
		foreach ($theme_fonts as $tag=>$v) {
			$fonts["{$tag}_section"] = array(
				"title" => !empty($v['title']) 
								? $v['title'] 
								// Translators: Add tag's name to make title 'H1 settings', 'P settings', etc.
								: esc_html(sprintf(esc_html__('%s settings', 'gardis'), $tag)),
				"desc" => !empty($v['description']) 
								? $v['description'] 
								// Translators: Add tag's name to make description
								: wp_kses( sprintf(__('Font settings of the "%s" tag.', 'gardis'), $tag), 'gardis_kses_content' ),
				"type" => "section",
				);
	
			foreach ($v as $css_prop=>$css_value) {
				if (in_array($css_prop, array('title', 'description'))) continue;
				$options = '';
				$type = 'text';
				$title = ucfirst(str_replace('-', ' ', $css_prop));
				if ($css_prop == 'font-family') {
					$type = 'select';
					$options = array();
				} else if ($css_prop == 'font-weight') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'gardis'),
						'100' => esc_html__('100 (Light)', 'gardis'), 
						'200' => esc_html__('200 (Light)', 'gardis'), 
						'300' => esc_html__('300 (Thin)',  'gardis'),
						'400' => esc_html__('400 (Normal)', 'gardis'),
						'500' => esc_html__('500 (Semibold)', 'gardis'),
						'600' => esc_html__('600 (Semibold)', 'gardis'),
						'700' => esc_html__('700 (Bold)', 'gardis'),
						'800' => esc_html__('800 (Black)', 'gardis'),
						'900' => esc_html__('900 (Black)', 'gardis')
					);
				} else if ($css_prop == 'font-style') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'gardis'),
						'normal' => esc_html__('Normal', 'gardis'), 
						'italic' => esc_html__('Italic', 'gardis')
					);
				} else if ($css_prop == 'text-decoration') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'gardis'),
						'none' => esc_html__('None', 'gardis'), 
						'underline' => esc_html__('Underline', 'gardis'),
						'overline' => esc_html__('Overline', 'gardis'),
						'line-through' => esc_html__('Line-through', 'gardis')
					);
				} else if ($css_prop == 'text-transform') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'gardis'),
						'none' => esc_html__('None', 'gardis'), 
						'uppercase' => esc_html__('Uppercase', 'gardis'),
						'lowercase' => esc_html__('Lowercase', 'gardis'),
						'capitalize' => esc_html__('Capitalize', 'gardis')
					);
				}
				$fonts["{$tag}_{$css_prop}"] = array(
					"title" => $title,
					"desc" => '',
					"class" => "gardis_column-1_5",
					"refresh" => false,
					"std" => '$gardis_get_theme_fonts_option',
					"options" => $options,
					"type" => $type
				);
			}
			
			$fonts["{$tag}_section_end"] = array(
				"type" => "section_end"
				);
		}

		$fonts['fonts_end'] = array(
			"type" => "panel_end"
			);

		// Add fonts parameters to Theme Options
		gardis_storage_set_array_before('options', 'panel_colors', $fonts);

		// Add Header Video if WP version < 4.7
		if (!function_exists('get_header_video_url')) {
			gardis_storage_set_array_after('options', 'header_image_override', 'header_video', array(
				"title" => esc_html__('Header video', 'gardis'),
				"desc" => wp_kses_data( __("Select video to use it as background for the header", 'gardis') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'gardis')
				),
				"std" => '',
				"type" => "video"
				)
			);
		}

		// Add option 'logo' if WP version < 4.5
		// or 'custom_logo' if current page is 'Theme Options'
		if (!function_exists('the_custom_logo') || (isset($_REQUEST['page']) && $_REQUEST['page']=='theme_options')) {
			gardis_storage_set_array_before('options', 'logo_retina', function_exists('the_custom_logo') ? 'custom_logo' : 'logo', array(
				"title" => esc_html__('Logo', 'gardis'),
				"desc" => wp_kses_data( __('Select or upload the site logo', 'gardis') ),
				"class" => "gardis_column-1_2 gardis_new_row",
				"priority" => 60,
				"std" => '',
				"type" => "image"
				)
			);
		}
	}
}


// Returns a list of options that can be overridden for CPT
if (!function_exists('gardis_options_get_list_cpt_options')) {
	function gardis_options_get_list_cpt_options($cpt, $title='') {
		if (empty($title)) $title = ucfirst($cpt);
		return array(
					"header_info_{$cpt}" => array(
						"title" => esc_html__('Header', 'gardis'),
						"desc" => '',
						"type" => "info",
						),
					"header_type_{$cpt}" => array(
						"title" => esc_html__('Header style', 'gardis'),
						"desc" => wp_kses_data( __('Choose whether to use the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'gardis') ),
						"std" => 'inherit',
						"options" => gardis_get_list_header_footer_types(true),
						"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
						),
					"header_style_{$cpt}" => array(
						"title" => esc_html__('Select custom layout', 'gardis'),
						// Translators: Add CPT name to the description
						"desc" => wp_kses_data( sprintf(__('Select custom layout to display the site header on the %s pages', 'gardis'), $title) ),
						"dependency" => array(
							"header_type_{$cpt}" => array('custom')
						),
						"std" => 'inherit',
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "select"
						),
					"header_position_{$cpt}" => array(
						"title" => esc_html__('Header position', 'gardis'),
						// Translators: Add CPT name to the description
						"desc" => wp_kses_data( sprintf(__('Select position to display the site header on the %s pages', 'gardis'), $title) ),
						"std" => 'inherit',
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
						),
					"header_image_override_{$cpt}" => array(
						"title" => esc_html__('Header image override', 'gardis'),
						"desc" => wp_kses_data( __("Allow override the header image with the post's featured image", 'gardis') ),
						"std" => 0,
						"type" => GARDIS_THEME_FREE ? "hidden" : "checkbox"
						),
					"header_widgets_{$cpt}" => array(
						"title" => esc_html__('Header widgets', 'gardis'),
						// Translators: Add CPT name to the description
						"desc" => wp_kses_data( sprintf(__('Select set of widgets to show in the header on the %s pages', 'gardis'), $title) ),
						"std" => 'hide',
						"options" => array(),
						"type" => "select"
						),
						
					"sidebar_info_{$cpt}" => array(
						"title" => esc_html__('Sidebar', 'gardis'),
						"desc" => '',
						"type" => "info",
						),
					"sidebar_position_{$cpt}" => array(
						"title" => esc_html__('Sidebar position', 'gardis'),
						// Translators: Add CPT name to the description
						"desc" => wp_kses_data( sprintf(__('Select position to show sidebar on the %s pages', 'gardis'), $title) ),
						"refresh" => false,
						"std" => 'left',
						"options" => array(),
						"type" => "switch"
						),
					"sidebar_widgets_{$cpt}" => array(
						"title" => esc_html__('Sidebar widgets', 'gardis'),
						// Translators: Add CPT name to the description
						"desc" => wp_kses_data( sprintf(__('Select sidebar to show on the %s pages', 'gardis'), $title) ),
						"dependency" => array(
							"sidebar_position_{$cpt}" => array('left', 'right')
						),
						"std" => 'hide',
						"options" => array(),
						"type" => "select"
						),
					"hide_sidebar_on_single_{$cpt}" => array(
						"title" => esc_html__('Hide sidebar on the single pages', 'gardis'),
						"desc" => wp_kses_data( __("Hide sidebar on the single page", 'gardis') ),
						"std" => 0,
						"type" => "checkbox"
						),
						
					"footer_info_{$cpt}" => array(
						"title" => esc_html__('Footer', 'gardis'),
						"desc" => '',
						"type" => "info",
						),
					"footer_type_{$cpt}" => array(
						"title" => esc_html__('Footer style', 'gardis'),
						"desc" => wp_kses_data( __('Choose whether to use the default footer or footer Layouts (available only if the ThemeREX Addons is activated)', 'gardis') ),
						"std" => 'inherit',
						"options" => gardis_get_list_header_footer_types(true),
						"type" => GARDIS_THEME_FREE ? "hidden" : "switch"
						),
					"footer_style_{$cpt}" => array(
						"title" => esc_html__('Select custom layout', 'gardis'),
						"desc" => wp_kses_data( __('Select custom layout to display the site footer', 'gardis') ),
						"std" => 'inherit',
						"dependency" => array(
							"footer_type_{$cpt}" => array('custom')
						),
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "select"
						),
					"footer_widgets_{$cpt}" => array(
						"title" => esc_html__('Footer widgets', 'gardis'),
						"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'gardis') ),
						"dependency" => array(
							"footer_type_{$cpt}" => array('default')
						),
						"std" => 'footer_widgets',
						"options" => array(),
						"type" => "select"
						),
					"footer_columns_{$cpt}" => array(
						"title" => esc_html__('Footer columns', 'gardis'),
						"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'gardis') ),
						"dependency" => array(
							"footer_type_{$cpt}" => array('default'),
							"footer_widgets_{$cpt}" => array('^hide')
						),
						"std" => 0,
						"options" => gardis_get_list_range(0,6),
						"type" => "select"
						),
					"footer_wide_{$cpt}" => array(
						"title" => esc_html__('Footer fullwide', 'gardis'),
						"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'gardis') ),
						"dependency" => array(
							"footer_type_{$cpt}" => array('default')
						),
						"std" => 0,
						"type" => "checkbox"
						),
						
					"widgets_info_{$cpt}" => array(
						"title" => esc_html__('Additional panels', 'gardis'),
						"desc" => '',
						"type" => GARDIS_THEME_FREE ? "hidden" : "info",
						),
					"widgets_above_page_{$cpt}" => array(
						"title" => esc_html__('Widgets at the top of the page', 'gardis'),
						"desc" => wp_kses_data( __('Select widgets to show at the top of the page (above content and sidebar)', 'gardis') ),
						"std" => 'hide',
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "select"
						),
					"widgets_above_content_{$cpt}" => array(
						"title" => esc_html__('Widgets above the content', 'gardis'),
						"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'gardis') ),
						"std" => 'hide',
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "select"
						),
					"widgets_below_content_{$cpt}" => array(
						"title" => esc_html__('Widgets below the content', 'gardis'),
						"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'gardis') ),
						"std" => 'hide',
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "select"
						),
					"widgets_below_page_{$cpt}" => array(
						"title" => esc_html__('Widgets at the bottom of the page', 'gardis'),
						"desc" => wp_kses_data( __('Select widgets to show at the bottom of the page (below content and sidebar)', 'gardis') ),
						"std" => 'hide',
						"options" => array(),
						"type" => GARDIS_THEME_FREE ? "hidden" : "select"
						)
					);
	}
}


// Return lists with choises when its need in the admin mode
if (!function_exists('gardis_options_get_list_choises')) {
	add_filter('gardis_filter_options_get_list_choises', 'gardis_options_get_list_choises', 10, 2);
	function gardis_options_get_list_choises($list, $id) {
		if (is_array($list) && count($list)==0) {
			if (strpos($id, 'header_style')===0)
				$list = gardis_get_list_header_styles(strpos($id, 'header_style_')===0);
			else if (strpos($id, 'header_position')===0)
				$list = gardis_get_list_header_positions(strpos($id, 'header_position_')===0);
			else if (strpos($id, 'header_widgets')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'header_widgets_')===0, true);
			else if (substr($id, -7) == '_scheme')
				$list = gardis_get_list_schemes($id!='color_scheme');
			else if (strpos($id, 'sidebar_widgets')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'sidebar_widgets_')===0, true);
			else if (strpos($id, 'sidebar_position')===0)
				$list = gardis_get_list_sidebars_positions(strpos($id, 'sidebar_position_')===0);
			else if (strpos($id, 'widgets_above_page')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'widgets_above_page_')===0, true);
			else if (strpos($id, 'widgets_above_content')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'widgets_above_content_')===0, true);
			else if (strpos($id, 'widgets_below_page')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'widgets_below_page_')===0, true);
			else if (strpos($id, 'widgets_below_content')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'widgets_below_content_')===0, true);
			else if (strpos($id, 'footer_style')===0)
				$list = gardis_get_list_footer_styles(strpos($id, 'footer_style_')===0);
			else if (strpos($id, 'footer_widgets')===0)
				$list = gardis_get_list_sidebars(strpos($id, 'footer_widgets_')===0, true);
			else if (strpos($id, 'blog_style')===0)
				$list = gardis_get_list_blog_styles(strpos($id, 'blog_style_')===0);
			else if (strpos($id, 'post_type')===0)
				$list = gardis_get_list_posts_types();
			else if (strpos($id, 'parent_cat')===0)
				$list = gardis_array_merge(array(0 => esc_html__('- Select category -', 'gardis')), gardis_get_list_categories());
			else if (strpos($id, 'blog_animation')===0)
				$list = gardis_get_list_animations_in();
			else if ($id == 'color_scheme_editor')
				$list = gardis_get_list_schemes();
			else if (strpos($id, '_font-family') > 0)
				$list = gardis_get_list_load_fonts(true);
		}
		return $list;
	}
}
?>